==> sddm_0.14.0.orig.tar.gz: sddm-0.14.0/data/translations/sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn">
<context>
    <name>PictureBox</name>
    <message>
        <location filename="../../components/2.0/PictureBox.qml" line="123"/>
        <source>Press to login</source>
        <translation>Tryck för att logga in</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/common/Session.cpp" line="137"/>
        <source>%1 (Wayland)</source>
        <translation>%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="28"/>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Varning, «Caps Lock» är på!</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="29"/>
        <source>Layout</source>
        <translation>Ritning</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="30"/>
        <source>Login</source>
        <translation>Logga in</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="31"/>
        <source>Login failed</source>
        <translation>Inloggningen misslyckades</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="32"/>
        <source>Login succeeded</source>
        <translation>Inloggningen misslyckades</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="33"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="34"/>
        <source>Enter your username and password</source>
        <translation>Ange användarnamn och lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="35"/>
        <source>Select your user and enter password</source>
        <translation>Välj din användare och ange lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="36"/>
        <source>Reboot</source>
        <translation>Starta om</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="37"/>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="38"/>
        <source>Shutdown</source>
        <translation>Stäng av</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="39"/>
        <source>User name</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="40"/>
        <source>Welcome to %1</source>
        <translation>Välkommen til %1</translation>
    </message>
</context>
</TS>

==> sddm-0.15.0.tar.gz: sddm-0.15.0/data/translations/sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn">
<context>
    <name>PictureBox</name>
    <message>
        <location filename="../../components/2.0/PictureBox.qml" line="123"/>
        <source>Press to login</source>
        <translation>Tryck för att logga in</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/common/Session.cpp" line="137"/>
        <source>%1 (Wayland)</source>
        <translation>%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="28"/>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Varning, «Caps Lock» är på!</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="29"/>
        <source>Layout</source>
        <translation>Tangentbordslayout</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="30"/>
        <source>Login</source>
        <translation>Logga in</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="31"/>
        <source>Login failed</source>
        <translation>Inloggningen misslyckades</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="32"/>
        <source>Login succeeded</source>
        <translation>Inloggningen lyckades</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="33"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="34"/>
        <source>Enter your username and password</source>
        <translation>Fyll i ditt användarnamn och lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="35"/>
        <source>Select your user and enter password</source>
        <translation>Välj din användare och ange lösenord</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="36"/>
        <source>Reboot</source>
        <translation>Starta om</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="37"/>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="38"/>
        <source>Shutdown</source>
        <translation>Stäng av</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="39"/>
        <source>User name</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../../components/common/TextConstants.qml" line="40"/>
        <source>Welcome to %1</source>
        <translation>Välkommen till %1</translation>
    </message>
</context>
</TS>
